@@ -16,10 +16,9 @@ Usage::
     session_client: SageMakerRuntimeClient = session.client("sagemaker-runtime")
     ```
 """
-from mypy_boto3_sagemaker_runtime.client import (
-    SageMakerRuntimeClient as Client,
-    SageMakerRuntimeClient,
-)
+from mypy_boto3_sagemaker_runtime.client import SageMakerRuntimeClient
+
+Client = SageMakerRuntimeClient
 
 
 __all__ = ("Client", "SageMakerRuntimeClient")
